/*

 (c) 2002 Brian Kelly under the terms of the GNU GPL
	http://www.gnu.org/copyleft/gpl.html

*/

#include <iostream.h>
#include <fstream.h>
#include <time.h>
#include <stdlib.h>
#include <string.h>
#include "trans.h"

void credit( char amt[], char com[] )
{
	char *file;
	file = getenv( "HOME" );

	strcat( file, "/.brinance/account" );

	ofstream fout;
	fout.open( file, ios::app );

	trans t( amt );

	cout << "Credit: " << t << endl;

	fout << "#";
	dateOut ( fout );
	fout << endl << "#" << com << endl;

	fout << t;

	fout.close();
}

